@@ -5,8 +5,8 @@
 ;; Author: Robb Enzmann <robbenzmann@gmail.com>
 ;; Keywords: treesitter auto automatic major mode fallback convenience
 ;; URL: https://github.com/renzmann/treesit-auto.git
-;; Package-Version: 1.0.5
-;; Package-Revision: v1.0.5-0-g09d1c8c4b5bd
+;; Package-Version: 1.0.9
+;; Package-Revision: v1.0.9-0-ge10d10adcf1a
 ;; Package-Requires: ((emacs "29.0"))
 
 ;; This file is not part of GNU Emacs.
@@ -71,7 +71,7 @@ by manipulating the `treesit-auto-recipe-list' variable."
 
 (cl-defstruct treesit-auto-recipe
   "Emacs metadata for a tree-sitter language grammar."
-  lang ts-mode remap requires url revision source-dir cc c++ ext)
+  lang ts-mode remap requires url revision abi14-revision source-dir cc c++ ext)
 
 (defvar treesit-auto-recipe-list
   `(,(make-treesit-auto-recipe
@@ -85,6 +85,7 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :ts-mode 'bash-ts-mode
       :remap 'sh-mode
       :url "https://github.com/tree-sitter/tree-sitter-bash"
+      :abi14-revision "v0.23.3"
       :ext "\\.sh\\'")
     ,(make-treesit-auto-recipe
       :lang 'bibtex
@@ -92,11 +93,18 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :remap 'bibtex-mode
       :url "https://github.com/latex-lsp/tree-sitter-bibtex"
       :ext "\\.bib\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'blueprint
+      :ts-mode 'blueprint-ts-mode
+      :remap 'blueprint-mode
+      :url "https://github.com/huanie/tree-sitter-blueprint"
+      :ext "\\.blp\\'")
     ,(make-treesit-auto-recipe
       :lang 'c
       :ts-mode 'c-ts-mode
       :remap 'c-mode
       :url "https://github.com/tree-sitter/tree-sitter-c"
+      :requires 'cpp
       :ext "\\.c\\'")
     ,(make-treesit-auto-recipe
       :lang 'c-sharp
@@ -116,6 +124,12 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :remap 'cmake-mode
       :url "https://github.com/uyha/tree-sitter-cmake"
       :ext "\\.cmake\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'cobol
+      :ts-mode 'cobol-ts-mode
+      :remap 'cobol-mode
+      :url "https://github.com/yutaro-sakamoto/tree-sitter-cobol"
+      :ext "\\.\\(cob\\|cbl\\)\\'")
     ,(make-treesit-auto-recipe
       :lang 'commonlisp
       :ts-mode 'commonlisp-ts-mode
@@ -126,7 +140,9 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :lang 'cpp
       :ts-mode 'c++-ts-mode
       :remap 'c++-mode
+      :requires 'c
       :url "https://github.com/tree-sitter/tree-sitter-cpp"
+      :revision "v0.22.0" ;; BUG: newer grammar breaks syntax highlighting in `c++-ts-mode'
       :ext "\\.cpp\\'")
     ,(make-treesit-auto-recipe
       :lang 'css
@@ -138,21 +154,26 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :lang 'dart
       :ts-mode 'dart-ts-mode
       :remap 'dart-mode
-      :url "https://github.com/ast-grep/tree-sitter-dart"
+      :url "https://github.com/UserNobody14/tree-sitter-dart"
       :ext "\\.dart\\'")
     ,(make-treesit-auto-recipe
       :lang 'dockerfile
       :ts-mode 'dockerfile-ts-mode
       :remap 'dockerfile-mode
       :url "https://github.com/camdencheek/tree-sitter-dockerfile"
-      :ext "\\Dockerfile\\'")
+      :ext "[/\\]\\(?:Containerfile\\|Dockerfile\\)\\(?:\\.[^/\\]*\\)?\\'")
     ,(make-treesit-auto-recipe
       :lang 'elixir
       :ts-mode 'elixir-ts-mode
       :remap 'elixir-mode
       :requires 'heex
       :url "https://github.com/elixir-lang/tree-sitter-elixir"
-      :ext "\\.ex\\'")
+      :ext "\\.exs?\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'gitcommit
+      :ts-mode 'git-commit-ts-mode
+      :url "https://github.com/gbprod/tree-sitter-gitcommit"
+      :ext "\\COMMIT_EDITMSG\\'")
     ,(make-treesit-auto-recipe
       :lang 'glsl
       :ts-mode 'glsl-ts-mode
@@ -164,6 +185,7 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :remap 'go-mode
       :requires 'gomod
       :url "https://github.com/tree-sitter/tree-sitter-go"
+      :abi14-revision "v0.23.4"
       :ext "\\.go\\'")
     ,(make-treesit-auto-recipe
       :lang 'gomod
@@ -171,7 +193,20 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :remap 'go-mod-mode
       :requires 'go
       :url "https://github.com/camdencheek/tree-sitter-go-mod"
+      :abi14-revision "v1.1.0"
       :ext "go\\.mod\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'gowork
+      :ts-mode 'go-work-ts-mode
+      :requires 'go
+      :url "https://github.com/omertuc/tree-sitter-go-work"
+      :ext "go\\.work\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'haskell
+      :ts-mode 'haskell-ts-mode
+      :remap 'haskell-mode
+      :url "https://github.com/tree-sitter/tree-sitter-haskell"
+      :ext "\\.hs\\'")
     ,(make-treesit-auto-recipe
       :lang 'heex
       :ts-mode 'heex-ts-mode
@@ -185,7 +220,12 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :url "https://github.com/tree-sitter/tree-sitter-html"
       :ext "\\.html\\'")
     ,(make-treesit-auto-recipe
-      :lang 'janet
+      :lang 'hyprlang
+      :ts-mode 'hyprlang-ts-mode
+      :url "https://github.com/tree-sitter-grammars/tree-sitter-hyprlang"
+      :ext "/hypr/.*\\.conf\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'janet-simple
       :ts-mode 'janet-ts-mode
       :remap 'janet-mode
       :url "https://github.com/sogaiu/tree-sitter-janet-simple"
@@ -204,6 +244,10 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :revision "master"
       :source-dir "src"
       :ext "\\.js\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'jsdoc
+      :ts-mode 'php-ts-mode
+      :url "https://github.com/tree-sitter/tree-sitter-jsdoc")
     ,(make-treesit-auto-recipe
       :lang 'json
       :ts-mode 'json-ts-mode
@@ -222,12 +266,6 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :remap 'kotlin-mode
       :url "https://github.com/fwcd/tree-sitter-kotlin"
       :ext "\\.kts?\\'")
-    ,(make-treesit-auto-recipe
-      :lang 'latex
-      :ts-mode 'latex-ts-mode
-      :remap 'latex-mode
-      :url "https://github.com/latex-lsp/tree-sitter-latex"
-      :ext "\\.tex\\'")
     ,(make-treesit-auto-recipe
       :lang 'lua
       :ts-mode 'lua-ts-mode
@@ -251,7 +289,14 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :ts-mode 'markdown-ts-mode
       :remap '(poly-markdown-mode markdown-mode)
       :url "https://github.com/tree-sitter-grammars/tree-sitter-markdown"
+      :source-dir "tree-sitter-markdown/src"
       :ext "\\.md\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'nix
+      :ts-mode 'nix-ts-mode
+      :remap 'nix-mode
+      :url "https://github.com/nix-community/tree-sitter-nix"
+      :ext "\\.nix\\'")
     ,(make-treesit-auto-recipe
       :lang 'nu
       :ts-mode 'nushell-ts-mode
@@ -270,6 +315,16 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :remap 'perl-mode
       :url "https://github.com/ganezdragon/tree-sitter-perl"
       :ext "\\.pl\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'php
+      :ts-mode 'php-ts-mode
+      :url "https://github.com/tree-sitter/tree-sitter-php"
+      :source-dir "php/src"
+      :ext "\\.php\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'phpdoc
+      :ts-mode 'php-ts-mode
+      :url "https://github.com/claytonrcarter/tree-sitter-phpdoc")
     ,(make-treesit-auto-recipe
       :lang 'proto
       :ts-mode 'protobuf-ts-mode
@@ -281,6 +336,7 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :ts-mode 'python-ts-mode
       :remap 'python-mode
       :url "https://github.com/tree-sitter/tree-sitter-python"
+      :abi14-revision "v0.23.6"
       :ext "\\.py[iw]?\\'")
     ,(make-treesit-auto-recipe
       :lang 'r
@@ -306,6 +362,12 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :remap 'scala-mode
       :url "https://github.com/tree-sitter/tree-sitter-scala"
       :ext "\\.\\(scala\\|sbt\\)\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'solidity
+      :ts-mode 'solidity-ts-mode
+      :remap 'solidity-mode
+      :url "https://github.com/JoranHonig/tree-sitter-solidity"
+      :ext "\\.sol\\'")
     ,(make-treesit-auto-recipe
       :lang 'sql
       :ts-mode 'sql-ts-mode
@@ -318,11 +380,16 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :ts-mode 'surface-ts-mode
       :remap 'surface-mode
       :url "https://github.com/connorlay/tree-sitter-surface")
+    ,(make-treesit-auto-recipe
+      :lang 'swift
+      :ts-mode 'swift-ts-mode
+      :remap 'swift-mode
+      :url "https://github.com/alex-pinkus/tree-sitter-swift")
     ,(make-treesit-auto-recipe
       :lang 'toml
       :ts-mode 'toml-ts-mode
       :remap '(conf-toml-mode toml-mode)
-      :url "https://github.com/tree-sitter/tree-sitter-toml"
+      :url "https://github.com/tree-sitter-grammars/tree-sitter-toml"
       :ext "\\.toml\\'")
     ,(make-treesit-auto-recipe
       :lang 'tsx
@@ -342,6 +409,13 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :revision "master"
       :source-dir "typescript/src"
       :ext "\\.ts\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'typespec
+      :ts-mode 'typespec-ts-mode
+      :url "https://github.com/happenslol/tree-sitter-typespec/"
+      :revision "main"
+      :source-dir "src"
+      :ext "\\.tsp\\'")
     ,(make-treesit-auto-recipe
       :lang 'typst
       :ts-mode 'typst-ts-mode
@@ -354,7 +428,7 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :lang 'verilog
       :ts-mode 'verilog-ts-mode
       :remap 'verilog-mode
-      :url "https://github.com/gmlarumbe/tree-sitter-verilog"
+      :url "https://github.com/gmlarumbe/tree-sitter-systemverilog"
       :ext "\\.s?vh?\\'")
     ,(make-treesit-auto-recipe
       :lang 'vhdl
@@ -382,6 +456,12 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :url "https://github.com/wasm-lsp/tree-sitter-wasm"
       :source-dir "wat/src"
       :ext "\\.wat\\'")
+    ,(make-treesit-auto-recipe
+      :lang 'zig
+      :ts-mode 'zig-ts-mode
+      :remap 'zig-mode
+      :url "https://github.com/maxxnino/tree-sitter-zig"
+      :ext "\\.zig\\'")
     ,(make-treesit-auto-recipe
       :lang 'wgsl
       :ts-mode 'wgsl-ts-mode
@@ -393,6 +473,7 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :ts-mode 'yaml-ts-mode
       :remap 'yaml-mode
       :url "https://github.com/tree-sitter-grammars/tree-sitter-yaml"
+      :abi14-revision "v0.7.2"
       :ext "\\.ya?ml\\'"))
   "Map each tree-sitter lang to Emacs metadata.")
 
@@ -500,11 +581,18 @@ Non-nil only if installation completed without any errors."
           (cl-loop for recipe in (treesit-auto--selected-recipes)
                    collect (cons (treesit-auto-recipe-lang recipe)
                                  `(,(treesit-auto-recipe-url recipe)
-                                   ,(treesit-auto-recipe-revision recipe)
+                                   ,(treesit-auto-get-revision recipe)
                                    ,(treesit-auto-recipe-source-dir recipe)
                                    ,(treesit-auto-recipe-cc recipe)
                                    ,(treesit-auto-recipe-c++ recipe))))))
 
+(defun treesit-auto-get-revision (recipe)
+  "Return the revision for recipe, potentially using abi14-revision."
+  (let ((default-revision (treesit-auto-recipe-revision recipe)))
+    (if (and (fboundp 'treesit-library-abi-version) (eq (treesit-library-abi-version) 14))
+	(or (treesit-auto-recipe-abi14-revision recipe) default-revision)
+      default-revision)))
+
 (defun treesit-auto-install-all ()
   "Install every available, maintained grammar.
 
